@@ -7,7 +7,7 @@ $dtc_database = array(
 	"admin" => array(
 		"vars" => array(
 			"adm_login" => "varchar(64) NOT NULL ",
-			"adm_pass" => "varchar(16) NOT NULL ",
+			"adm_pass" => "varchar(255) NOT NULL ",
 			"path" => "varchar(128) NOT NULL default '/web/disk4' ",
 			"max_email" => "int(12) NOT NULL default '3' ",
 			"max_ftp" => "int(12) NOT NULL default '3' ",
@@ -591,7 +591,7 @@ $dtc_database = array(
 			"gateway" => "varchar(16) NOT NULL default ''",
 			"broadcast" => "varchar(16) NOT NULL default ''",
 			"dns" => "varchar(16) NOT NULL default ''",
-			"zone_type" => "enum('support_ticket','ip_per_ip','one_zonefile') default 'one_zonefile'",
+			"zone_type" => "enum('support_ticket','ip_per_ip','ip_per_ip_cidr','one_zonefile') default 'one_zonefile'",
 			"custom_part" => "text NOT NULL"
 			),
 		"primary" => "(id)",
