@@ -171,6 +171,39 @@ function get_remote_ns_domains(){
 	return $domain_list;
 }
 
+function calculate_reverse_mask_and_cidr($ip_pool_ip,$ip_pool_netmask){
+	$ip_pool_ip_exploded = explode(".",$ip_pool_ip);
+
+	$netmask_exploded = explode(".",$ip_pool_netmask);
+	switch($ip_pool_netmask){
+	case "255.255.255.128":
+		$cird_mask = "/25";
+		break;
+	case "255.255.255.192":
+		$cird_mask = "/26";
+		break;
+	case "255.255.255.224":
+		$cird_mask = "/27";
+		break;
+	case "255.255.255.240":
+		$cird_mask = "/28";
+		break;
+	case "255.255.255.248":
+		$cird_mask = "/29";
+		break;
+	case "255.255.255.252":
+		$cird_mask = "/30";
+		break;
+	case "255.255.255.254":
+		$cird_mask = "/31";
+		break;
+	default:
+		die("$netmask is not a netmask line ".__LINE__." file ".__FILE__);
+	}
+	$out = "." . $ip_pool_ip_exploded[3] . $cird_mask . "." . $ip_pool_ip_exploded[2] . "." . $ip_pool_ip_exploded[1] . "." . $ip_pool_ip_exploded[0] . ".in-addr.arpa";;
+	return $out;
+}
+
 function calculate_reverse_end($ip_pool_ip,$ip_pool_netmask){
 	$out = "";
 	$ip_pool_ip_exploded = explode(".",$ip_pool_ip);
@@ -267,6 +300,8 @@ function rnds_generate(){
 	global $conf_named_soa_expire;
 	global $conf_named_soa_default_ttl;
 
+	global $conf_ip_slavezone_dns_server;
+
         $todays_serial = date("YmdH");
 	// Calculate the: allow-transfer { 203.174.86.120; 203.174.86.121; };
 	// string that we have to add
@@ -321,8 +356,6 @@ function rnds_generate(){
 	AND $pro_mysql_ip_pool_table.id=$pro_mysql_dedicated_ips_table.ip_pool_id;";
 	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
 	$num_ded = mysql_num_rows($r);
-	unset($tbl);
-	$tbl = array();
 	$tbl_num_of_records = $num_vps + $num_ded;
 	for($i=$num_vps;$i<$tbl_num_of_records;$i++){
 		$a = mysql_fetch_array($r);
@@ -343,6 +376,7 @@ function rnds_generate(){
 
 		switch($zone_type){
 		case "ip_per_ip":
+		case "ip_per_ip_cidr":
 			unset($thiszoneIPs);
 			unset($thiszoneVPSIPs);
 			unset($thiszoneDEDIPs);
@@ -369,17 +403,27 @@ function rnds_generate(){
 			for($j=0;$j<$num_of_IPs;$j++){
 				$the_ip_addr = $thiszoneIPs[$j]["ip_addr"];
 				$the_reverse = $thiszoneIPs[$j]["rdns_addr"];
-				$zone_name = calculate_reverse_end($the_ip_addr,"255.255.255.255");
-				$reverse_dns_file .= "zone \"$zone_name\" in {
+				if($zone_type == "ip_per_ip_cidr"){
+					$zone_name_end = calculate_reverse_mask_and_cidr($pool_ip_addr,$pool_netmask);
+					$ip_exploded = explode(".",$the_ip_addr);
+					$zone_name = $ip_exploded[3] . $zone_name_end;
+					$the_at = "$zone_name\t";
+					$the_orig = "\$ORIGIN .\n";
+				}else{
+					$zone_name = calculate_reverse_end($the_ip_addr,"255.255.255.255");
+					$the_at = "@\t";
+					$the_orig = "";
+				}
+/*				$reverse_dns_file .= "zone \"$zone_name\" in {
 	type master;
 	file \"$conf_generated_file_path/reverse_zones/$the_ip_addr\";
 $allow_trans_str	allow-query { any; };
 };
 
-";
+";*/
 
-				$zonefile_content = "\$TTL $conf_default_zones_ttl
-@	$conf_default_zones_ttl	IN	SOA	".$conf_addr_primary_dns.". ".$bind_formated_webmaster_email_addr." (
+				$zonefile_content = $the_orig."\$TTL $conf_default_zones_ttl
+$the_at	$conf_default_zones_ttl	IN	SOA	".$conf_addr_primary_dns.". ".$bind_formated_webmaster_email_addr." (
 			$todays_serial; serial
 			$conf_named_soa_refresh ; refresh
 			$conf_named_soa_retry ; retry
@@ -400,13 +444,13 @@ $allow_trans_str	allow-query { any; };
 			break;
 		case "one_zonefile":
 			$zone_name = calculate_reverse_end($pool_ip_addr,$pool_netmask);
-			$reverse_dns_file .= "zone \"$zone_name\" in {
+/*			$reverse_dns_file .= "zone \"$zone_name\" in {
 	type master;
 	file \"$conf_generated_file_path/reverse_zones/$pool_ip_addr\";
 $allow_trans_str	allow-query { any; };
 };
 
-";
+";*/
 			// FIXME: need to use the same kind of technique for the zonefile serial increment as bellow...
 			$zonefile_content = "\$TTL $conf_default_zones_ttl
 @	$conf_default_zones_ttl	IN	SOA	".$conf_addr_primary_dns.". ".$bind_formated_webmaster_email_addr." (
@@ -481,6 +525,89 @@ $allow_trans_str	allow-query { any; };
 		$r2 = mysql_query($q2)or die("Cannot query $q2 line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
 	}
 
+
+	$q = "SELECT id,ip_addr,netmask,zone_type,custom_part FROM $pro_mysql_ip_pool_table;";
+	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+	$n = mysql_num_rows($r);
+	for($i=0;$i<$n;$i++){
+		$a = mysql_fetch_array($r);
+		$ip_pool_id = $a["id"];
+		$pool_ip_addr = $a["ip_addr"];
+		$pool_netmask = $a["netmask"];
+		$zone_type = $a["zone_type"];
+		$custom_part = $a["custom_part"];
+
+		switch($zone_type){
+		case "ip_per_ip":
+		case "ip_per_ip_cidr":
+			unset($thiszoneIPs);
+			unset($thiszoneVPSIPs);
+			unset($thiszoneDEDIPs);
+			$thiszoneIPs = array();
+			$q2 = "SELECT * FROM $pro_mysql_vps_ip_table WHERE ip_pool_id='$ip_pool_id';";
+			$r2 = mysql_query($q2)or die("Cannot query $q2 line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
+			$num_vps = mysql_num_rows($r2);
+			for($j=0;$j<$num_vps;$j++){
+				$a2 = mysql_fetch_array($r2);
+				$thiszoneIPs[] = $a2;
+			}
+			$q2 = "SELECT * FROM $pro_mysql_dedicated_ips_table WHERE ip_pool_id='$ip_pool_id';";
+			$r2 = mysql_query($q2)or die("Cannot query $q2 line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
+			$num_ded = mysql_num_rows($r2);
+			for($j=0;$j<$num_ded;$j++){
+				$a2 = mysql_fetch_array($r2);
+				$thiszoneIPs[] = $a2;
+			}
+			$num_of_IPs = sizeof($thiszoneIPs);
+			for($j=0;$j<$num_of_IPs;$j++){
+				$the_ip_addr = $thiszoneIPs[$j]["ip_addr"];
+				if($zone_type == "ip_per_ip_cidr"){
+					$zone_name_end = calculate_reverse_mask_and_cidr($pool_ip_addr,$pool_netmask);
+					$ip_exploded = explode(".",$the_ip_addr);
+					$zone_name = $ip_exploded[3] . $zone_name_end;
+				}else{
+					$zone_name = calculate_reverse_end($the_ip_addr,"255.255.255.255");
+				}
+				$reverse_dns_file .= "zone \"$zone_name\" in {
+	type master;
+	file \"$conf_generated_file_path/reverse_zones/$the_ip_addr\";
+$allow_trans_str	allow-query { any; };
+};
+
+";
+				$slave_dns_file .= "zone \"$zone_name\" in {
+	type slave;
+	file \"$conf_generated_file_path/slave_reverse_zones/$the_ip_addr\";
+	masters { $conf_ip_slavezone_dns_server; };
+	allow-query { any; };
+};
+
+";
+			}
+			break;
+		case "one_zonefile":
+			$zone_name = calculate_reverse_end($pool_ip_addr,$pool_netmask);
+			$reverse_dns_file .= "zone \"$zone_name\" in {
+	type master;
+	file \"$conf_generated_file_path/reverse_zones/$pool_ip_addr\";
+$allow_trans_str	allow-query { any; };
+};
+
+";
+			$slave_dns_file .= "zone \"$zone_name\" in {
+	type slave;
+	file \"$conf_generated_file_path/slave_reverse_zones/$pool_ip_addr\";
+	masters { $conf_ip_slavezone_dns_server; };
+	allow-query { any; };
+};
+
+";
+			break;
+		default:
+			break;
+		}
+	}
+
 	// Write the $reverse_dns_file
 	$filep = fopen("$conf_generated_file_path/named.conf.reverse", "w+");
 	if( $filep == NULL){
@@ -494,7 +621,7 @@ $allow_trans_str	allow-query { any; };
 	if( $filep == NULL){
 		die("Cannot open file \"$conf_generated_file_path/named.conf.slave.reverse\" for writting");
 	}
-	fwrite($filep,$reverse_dns_file);
+	fwrite($filep,$slave_dns_file);
 	fclose($filep);
 }
 
@@ -517,11 +644,14 @@ function nodes_vps_generate(){
 	global $conf_dtc_system_username;
 	global $conf_ip_allowed_dns_transfer;
 
+	global $conf_ip_slavezone_dns_server;
+
 	global $conf_webmaster_email_addr;
 
 	$bind_formated_webmaster_email_addr = str_replace('@',".",$conf_webmaster_email_addr).".";
 
-	$nodes_named_conf = "";
+	$nodes_named_conf = "// WARNING: Automatic regeneration of this file, do not edit!\n";
+	$nodes_named_conf_slave = "//WARNING: Automatic regeneration of this file, do not edit!\n";
 
 	$all_ip = "";
 	if(strlen($conf_ip_allowed_dns_transfer) > 4){
@@ -544,6 +674,15 @@ function nodes_vps_generate(){
 		$a = mysql_fetch_array($r);
 		$srv_hostname = $a["hostname"];
 
+		$nodes_named_conf_slave .= "zone \"$srv_hostname\" IN {
+	type slave;
+	file \"$conf_generated_file_path/nodes_zones/$srv_hostname\";
+	masters { $conf_ip_slavezone_dns_server; };
+	allow-query { any; };
+};
+
+";
+
 		$nodes_named_conf .= "
 zone \"$srv_hostname\" IN {
         type master;
@@ -594,6 +733,11 @@ zone \"$srv_hostname\" IN {
 		fwrite($filep,$nodes_named_conf);
 		fclose($filep);
 		@chown("$conf_generated_file_path/nodes_zones.conf",$conf_dtc_system_username);
+
+		$filep = fopen("$conf_generated_file_path/nodes_zones_slave.conf","w+");
+		fwrite($filep,$nodes_named_conf_slave);
+		fclose($filep);
+		@chown("$conf_generated_file_path/nodes_zones.conf",$conf_dtc_system_username);
 	}
 }
 
@@ -876,7 +1020,7 @@ $more_mx_server
 				$KEY = str_replace("\n","",$KEY);
 				$SELECTOR="postfix";
 				$DOMAIN=$web_name;
-				$NSRECORD="$SELECTOR._domainkey IN TXT \"k=rsa;p=$KEY; t=y\"";
+				$NSRECORD="$SELECTOR._domainkey IN TXT \"k=rsa;p=$KEY\"";
 				$NSRECORDDEFAULT="_domainkey IN TXT \"o=~\"";
 				$this_site_file .= "$NSRECORDDEFAULT\n";
 				$this_site_file .= "$NSRECORD\n";
