@@ -52,8 +52,12 @@ function mail_account_generate_postfix(){
 	global $conf_use_mail_alias_group;
 
 	global $conf_support_ticket_email;
+	global $conf_support_ticket_domain;
 	global $conf_main_domain;
 
+	global $adm_realpass;
+	global $adm_pass;
+	global $adm_random_pass;
 	//global $conf_postfix_virtual_mailbox_domains_path;
 	//global $conf_postfix_virtual_path;
 	//global $conf_postfix_vmailbox_path;
@@ -106,6 +110,10 @@ function mail_account_generate_postfix(){
 		$row = mysql_fetch_array($result) or die ("Cannot fetch user-admin");
 		$user_admin_name = $row["adm_login"];
 		$user_admin_pass = $row["adm_pass"];
+		$adm_realpass = $row["adm_pass"];
+		$adm_pass = $row["adm_pass"];
+		$adm_random_pass = $row["adm_pass"];
+
 		$admin = fetchAdmin($user_admin_name,$user_admin_pass);
 		if(($error = $admin["err"]) != 0){
 			die("Error fetching admin : $error");
@@ -227,7 +235,7 @@ function mail_account_generate_postfix(){
 					if (!isset($home) || $home=="" && $conf_use_cyrus != "yes"){
 						$console .= "Missing home variable for $id";
 					}
-					if(! is_dir($home) && ($conf_use_cyrus != "yes")){
+					if(! is_dir($home) && ($conf_use_cyrus != "yes") && strlen($home) > 0 && $id != "cyrus" && $id != "cyradm"){
 						$PATH = getenv('PATH');
 						putenv("PATH=/usr/lib/courier-imap/bin:$PATH");
 						system("/bin/mkdir -p $home && maildirmake $home");
@@ -303,7 +311,7 @@ function mail_account_generate_postfix(){
 							genDotMailfilterFile($home,$id,$domain_full_name,$spam_mailbox_enable,$spam_mailbox,$localdeliver,$vacation_flag,$vacation_text,$redirect1,$redirect2);
 						}
 					}
-					if(is_dir($home) && $homedir_created == 1){
+					if(is_dir($home) && $homedir_created == 1 && $id != "cyrus" && $id != "cyradm"){
 						system("chown -R $conf_dtc_system_username $home");
 					}
 					if ( $k==$nbr_boites-1 ) $domains_postmasters_file.= "#\n";
@@ -424,7 +432,7 @@ function mail_account_generate_postfix(){
 
 	// Add the support@ email
 	$aliases_file .= "dtc_support_ticket_messages: \"|/usr/share/dtc/admin/support-receive.php\"\n";
-	$domains_postmasters_file .= $conf_support_ticket_email."@".$conf_main_domain." dtc_support_ticket_messages\n";
+	$domains_postmasters_file .= $conf_support_ticket_email."@".$conf_support_ticket_domain." dtc_support_ticket_messages\n";
 
 	//write out our config files
 	$fp = fopen ( "$conf_postfix_virtual_mailbox_domains_path", "w");
