@@ -161,6 +161,7 @@ function pro_vhost_generate(){
 	global $pro_mysql_admin_table;
 	global $pro_mysql_subdomain_table;
 	global $pro_mysql_ssl_ips_table;
+	global $pro_mysql_product_table;
 
 	global $conf_db_version;
 	global $conf_unix_type;
@@ -196,8 +197,13 @@ function pro_vhost_generate(){
 	global $conf_mysql_db;
 
 	global $conf_apache_version;
+	global $conf_apache_directoryindex;
+
+	global $conf_autogen_webmail_alias;
+	global $conf_autogen_webmail_type;
 
 	$vhost_file = "";
+
 	$logrotate_file = "# Do not edit this file, it's generated
 # edit /etc/dtc/logrotate.template instead!
 ";
@@ -285,13 +291,16 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 					$vhost_file .= "<VirtualHost ".$all_site_addrs[$i].":80>
 	ServerName $conf_404_subdomain.$conf_main_domain
 	DocumentRoot $path_404/html
+	<Directory $path_404/html>
+		Allow from all
+	</Directory>
 	ScriptAlias /cgi-bin $path_404/cgi-bin
 	ErrorLog $path_404/logs/error.log
 	LogSQLTransferLogTable ".str_replace("-","A",str_replace(".","_",$conf_main_domain)).'$'.$conf_404_subdomain.'$'."xfer
 	LogSQLScoreDomain $conf_main_domain
 	LogSQLScoreSubdomain $conf_404_subdomain
 	LogSQLScoreTable $conf_mysql_db.http_accounting
-	DirectoryIndex index.php index.cgi index.pl index.htm index.html index.php4
+	DirectoryIndex $conf_apache_directoryindex
 </VirtualHost>\n";
 					$logrotate_file .= "$path_404/logs/error.log ";
 				}
@@ -327,7 +336,7 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
         LogSQLScoreDomain $conf_main_domain
         LogSQLScoreSubdomain $conf_404_subdomain
         LogSQLScoreTable $conf_mysql_db.http_accounting
-        DirectoryIndex index.php index.cgi index.pl index.htm index.html index.php4
+        DirectoryIndex $conf_apache_directoryindex
 </VirtualHost>\n";
 			$logrotate_file .= "$path_404/logs/error.log ";
 		}
@@ -348,14 +357,44 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 	Order Deny,Allow
 	Allow from all
 </Directory>\n";
-//	This is not needed anymore as we don't use cgi-bin for the rrdtool graphing anymore
-//	If you need it for your specific config, then add it in the main apache config
-//	if($conf_unix_type == "debian"){
-//		$vhost_file .= "ScriptAlias /cgi-bin /usr/lib/cgi-bin
-//<Directory /usr/lib/cgi-bin>
-//	Options FollowSymLinks
-//</Directory>\n";
-//	}
+
+	if($conf_autogen_webmail_alias == "yes"){
+		if($conf_autogen_webmail_type == "squirrelmail"){
+			$vhost_file .= "RedirectPermanent /webmail https://$conf_administrative_site/squirrelmail\n";
+		}else{
+			$vhost_file .= "RedirectPermanent /webmail https://$conf_administrative_site/roundcube\n";
+		}
+	}
+
+	#############################
+	# mod_cband user generation #
+	#############################
+	$vhost_file .= "<IfModule mod_cband.c>\n";
+	$q = "SELECT DISTINCT adm_login,$pro_mysql_product_table.bandwidth FROM $pro_mysql_domain_table,$pro_mysql_admin_table,$pro_mysql_product_table
+WHERE $pro_mysql_domain_table.owner=$pro_mysql_admin_table.adm_login
+AND $pro_mysql_product_table.id=$pro_mysql_admin_table.prod_id
+AND $pro_mysql_admin_table.prod_id != '0'
+AND $pro_mysql_admin_table.id_client != '0'";
+	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+	$n = mysql_num_rows($r);
+	for($i=0;$i<$n;$i++){
+		$a = mysql_fetch_array($r);
+		$vhost_file .= "
+<CBandUser ".$a["adm_login"].">
+	CBandSpeed 10Mbps 10 30
+	CBandRemoteSpeed 2Mbps 3 3
+	CBandLimit ".$a["bandwidth"]."M
+	CBandPeriod 4W
+	CBandPeriodSlice 1W
+	CBandExceededSpeed 32kbps 2 5
+	CBandUserScoreboard /var/lib/dtc/etc/cband_scores/".$a["adm_login"]."
+</CBandUser>
+";
+	}
+	$vhost_file .= "</IfModule>\n";
+	#################################
+	# end mod_cband user generation #
+	#################################
 
 	for($i=0;$i<$num_rows;$i++){
 		$row = mysql_fetch_array($result) or die ("Cannot fetch user");
@@ -370,6 +409,10 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 		$domain_safe_mode = $row["safe_mode"];
 		$domain_sbox_protect = $row["sbox_protect"];
 		$domain_parking = $row["domain_parking"];
+		$domain_parking_type = $row["domain_parking_type"];
+		$domain_wildcard_dns = $row["wildcard_dns"];
+		$domain_default_sub_server_alias = $row["default_sub_server_alias"];
+
 		unset($backup_ip_addr);
 		if (isset($row["backup_ip_addr"])){
 			$backup_ip_addr = $row["backup_ip_addr"];
@@ -403,7 +446,8 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 		$result2 = mysql_query ($query2)or die("Cannot execute query \"$query2\"");
 		$num_rows2 = mysql_num_rows($result2);
 		if($num_rows2 != 1){
-			die("No user of that name !");
+			echo("No user of that name ($web_owner)!\n");
+			continue;
 		}
 		$webadmin = mysql_fetch_array($result2) or die ("Cannot fetch user");
 		$web_path = $webadmin["path"];
@@ -429,19 +473,37 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 
 		// Grab all subdomains
 		if($web_name == $conf_main_domain){
-			$query2 = "SELECT * FROM $pro_mysql_subdomain_table WHERE domain_name='$web_name' AND ip='default' AND subdomain_name!='$conf_404_subdomain' ORDER BY subdomain_name;";
+			$query2 = "SELECT * FROM $pro_mysql_subdomain_table WHERE domain_name='$web_name' AND ip='default' AND subdomain_name!='$conf_404_subdomain' AND subdomain_name!='$web_default_subdomain' ORDER BY subdomain_name;";
 		}else{
-			$query2 = "SELECT * FROM $pro_mysql_subdomain_table WHERE domain_name='$domain_to_get' AND ip='default' ORDER BY subdomain_name;";
+			$query2 = "SELECT * FROM $pro_mysql_subdomain_table WHERE domain_name='$domain_to_get' AND ip='default' AND subdomain_name!='$web_default_subdomain' ORDER BY subdomain_name;";
 		}
 		$result2 = mysql_query ($query2)or die("Cannot execute query \"$query2\"");
 		$num_rows2 = mysql_num_rows($result2);
+
+		unset($temp_array_subs);
+		$temp_array_subs = array();
+		for($j=0;$j<$num_rows2;$j++){
+			$temp_array_subs[] = mysql_fetch_array($result2) or die ("Cannot fetch user line ".__LINE__." file ".__FILE__);
+		}
+
+		// We get the default subdomain and we add it at the end of the array. The goal is to have the
+		// wildcard subdomain be the last in the list of the vhosts.conf
+		$query2 = "SELECT * FROM $pro_mysql_subdomain_table WHERE domain_name='$domain_to_get' AND ip='default' AND subdomain_name='$web_default_subdomain';";
+		$result2 = mysql_query ($query2)or die("Cannot execute query \"$query2\"");
+		$my_num_rows = mysql_num_rows($result2);
+		if($my_num_rows == 1){
+			$temp_array_subs[] = mysql_fetch_array($result2) or die ("Cannot fetch user".__LINE__." file ".__FILE__);
+			$num_rows2++;
+		}
+
 // This is a bad idea to die in this case
 // because it actualy happen if you redirect www ip to something else.
 //		if($num_rows2 < 1){
 //			die("No subdomain for domain $web_name !");
 //		}
 		for($j=0;$j<$num_rows2;$j++){
-			$subdomain = mysql_fetch_array($result2) or die ("Cannot fetch user");
+			$subdomain = $temp_array_subs[$j];
+//			$subdomain = mysql_fetch_array($result2) or die ("Cannot fetch user");
 			$web_subname = $subdomain["subdomain_name"];
 			if( $subdomain["customize_vhost"] == ""){
 				$custom_directives = "";
@@ -510,7 +572,8 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 					$alias_user_result = mysql_query($alias_user_query) or die("Cannot fetch user for Alias");
 					$num_rows_alias_user = mysql_num_rows($alias_user_result);
 					if ($num_rows_alias_user != 1) {
-						die("No user of that name!");
+						echo("No user of that name ($web_ownerX)!\n");
+						continue;
 					}
 					$alias_path = mysql_fetch_array($alias_user_result) or die ("Cannot fetch user");
 					$web_pathX = $alias_path["path"];
@@ -547,6 +610,9 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 					$vhost_file .= "	SSLEngine on
 	SSLCertificateFile ".$conf_generated_file_path."/ssl/new.cert.cert
 	SSLCertificateKeyFile ".$conf_generated_file_path."/ssl/new.cert.key\n";
+					if (file_exists($conf_generated_file_path."/ssl/new.cert.ca")) {
+						$vhost_file .= "	SSLCertificateChainFile ".$conf_generated_file_path."/ssl/new.cert.ca\n";
+					}
 				}
 				vhost_chk_dir_sh("$web_path/$web_name/subdomains/$web_subname/html");
 				vhost_chk_dir_sh("$web_path/$web_name/subdomains/$web_subname/logs");
@@ -557,11 +623,14 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 	Alias /dtcemail $conf_dtcemail_path
 	Alias /dtcadmin $conf_dtcadmin_path
 	Alias /stats $web_path/$web_name/subdomains/$web_subname/logs
-	Alias /awstats-icon /usr/share/awstats/icon
+	Alias /awstats-icon $conf_tools_prefix/awstats/icon
 	Alias /squirrelmail ".$conf_tools_prefix."/squirrelmail
 	Alias /roundcube /var/lib/roundcube
 	php_admin_value sendmail_from webmaster@$web_name
 	DocumentRoot $web_path/$web_name/subdomains/$web_subname/html
+	<Directory $web_path/$web_name/subdomains/$web_subname/html>
+		Allow from all
+	</Directory>
 # No ScriptAlias: we want to use system's /usr/lib/cgi-bin !!!
 #	ScriptAlias /cgi-bin $web_path/$web_name/subdomains/$web_subname/cgi-bin
 	ErrorLog $web_path/$web_name/subdomains/$web_subname/logs/error.log
@@ -569,7 +638,13 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 	LogSQLScoreDomain $web_name
 	LogSQLScoreSubdomain $web_subname
 	LogSQLScoreTable $conf_mysql_db.http_accounting
-	DirectoryIndex index.php index.cgi index.pl index.htm index.html index.php4$custom_directives
+	DirectoryIndex $conf_apache_directoryindex$custom_directives
+	<IfModule mod_bwshare.c>
+		BW_throttle_off 1
+	</IfModule>
+	<IfModule mod_security2.c>
+		SecRuleEngine Off
+        </IfModule>
 </VirtualHost>
 
 ";
@@ -581,7 +656,7 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 // ---------------------------------------------------
 			} else {
 				// Generate a permanet redirect for all subdomains of target if using a domain parking
-				if($domain_parking != "no-parking"){
+				if($domain_parking != "no-parking" && ($domain_parking_type == "redirect" || $conf_administrative_site == "$web_subname.$domain_to_get")){
 					if($j == 0){
 						$console .= "Making domain parking for $web_name\n";
 						$vhost_file .= "<VirtualHost ".$ip_to_write.":80>
@@ -594,13 +669,21 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 	ServerName $web_subname.$web_name
 	Redirect permanent / http://$web_subname.$domain_parking/
 </VirtualHost>\n\n";
+                                } else if ($domain_parking != "no-parking" && $domain_parking_type == "serveralias") {
+                                        // do nothing here, as serveralias parking will be injected throughout the generation of the main domain
 				}else{
-					vhost_chk_dir_sh("$web_path/$web_name/subdomains/$web_subname/logs");
-					vhost_chk_dir_sh("$web_path/$web_name/subdomains/$web_subname/html");
-					vhost_chk_dir_sh("$web_path/$web_name/subdomains/$web_subname/cgi-bin");
+					vhost_chk_dir_sh("$web_path/$domain_to_get/subdomains/$web_subname/logs");
+					vhost_chk_dir_sh("$web_path/$domain_to_get/subdomains/$web_subname/html");
+					vhost_chk_dir_sh("$web_path/$domain_to_get/subdomains/$web_subname/cgi-bin");
+					// We need to make it for both in case of a domain parking
+					if($domain_to_get != $web_name){
+						vhost_chk_dir_sh("$web_path/$web_name/subdomains/$web_subname/logs");
+						vhost_chk_dir_sh("$web_path/$web_name/subdomains/$web_subname/html");
+						vhost_chk_dir_sh("$web_path/$web_name/subdomains/$web_subname/cgi-bin");
+					}
 					$iteration_table = array();
 					$iteration_table[] = "normal";
-					$ssl_cert_folder_path = "$web_path/$web_name/subdomains/$web_subname/ssl";
+					$ssl_cert_folder_path = "$web_path/$domain_to_get/subdomains/$web_subname/ssl";
 					if($subdomain["ssl_ip"] != "none"){
 						$ssl_returns = checkCertificate($ssl_cert_folder_path,$web_subname.".".$web_name);
 						if($ssl_returns == "yes"){
@@ -640,7 +723,35 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 						$vhost_more_conf .= "	php_admin_value register_globals 1\n";
 					}
 					if($web_subname == "$web_default_subdomain"){
-						$vhost_more_conf .= "	ServerAlias $web_name\n";
+						if ($domain_parking == "no-parking"){
+							// no domain parking
+							$server_alias_domain = $domain_to_get;
+						} else {
+							// parking: same_docroot
+							$server_alias_domain = $web_name;
+							// parking: redirect doesn't happen in this else branch
+						}
+						if($domain_default_sub_server_alias == "yes"){
+							$vhost_more_conf .= "	ServerAlias $server_alias_domain\n";
+						}
+						if($domain_wildcard_dns == "yes"){
+							$vhost_more_conf .= "   ServerAlias *.$server_alias_domain\n";
+						}
+					}
+
+					// ServerAlias for parked domains
+					$q_serveralias = "select * from $pro_mysql_domain_table where domain_parking_type='serveralias' and domain_parking='$web_name'";
+					$r_serveralias = mysql_query($q_serveralias) or die("Cannot query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+					while ($row_serveralias = mysql_fetch_array($r_serveralias)) {
+						// default subdomain and wildcard subdomain settings are inherited from the main domain, not the parked domain
+						// this is because in the gui these settings are not accessable for a parked domain
+						if ($web_subname == "$web_default_subdomain") {
+							$vhost_more_conf .= "        ServerAlias ${row_serveralias["name"]}\n";
+						}
+						$vhost_more_conf .= "        ServerAlias $web_subname.${row_serveralias["name"]}\n";
+						if ($domain_wildcard_dns == "yes") {
+							$vhost_more_conf .= "        ServerAlias *.${row_serveralias["name"]}\n";
+						}
 					}
 
 					// Sbox and safe mode protection values
@@ -650,7 +761,7 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 						$safe_mode_value = "1";
 					}
 					if($domain_sbox_protect == "no" && $subdomain["sbox_protect"] == "no"){
-						$cgi_directive = "ScriptAlias /cgi-bin $web_path/$web_name/subdomains/$web_subname/cgi-bin";
+						$cgi_directive = "ScriptAlias /cgi-bin $web_path/$domain_to_get/subdomains/$web_subname/cgi-bin";
 					}else{
 						$cgi_directive = "RewriteEngine on
 	RewriteRule ^/cgi-bin/(.*) /cgi-bin/sbox/$1 [PT]";
@@ -671,8 +782,11 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 							$vhost_file .= "Listen ".$subdomain["ssl_ip"].":$port\n";
 							$vhost_file .= "<VirtualHost ".$subdomain["ssl_ip"].":$port>\n";
 							$vhost_file .= "	SSLEngine on\n";
-							$vhost_file .= "	SSLCertificateFile $ssl_cert_folder_path/".$web_subname.".".$web_name.".cert.cert\n";
-							$vhost_file .= "	SSLCertificateKeyFile $ssl_cert_folder_path/".$web_subname.".".$web_name.".cert.key\n";
+							$vhost_file .= "	SSLCertificateFile $ssl_cert_folder_path/".$web_subname.".".$domain_to_get.".cert.cert\n";
+							$vhost_file .= "	SSLCertificateKeyFile $ssl_cert_folder_path/".$web_subname.".".$domain_to_get.".cert.key\n";
+		                                        if (file_exists("$ssl_cert_folder_path/".$web_subname.".".$domain_to_get.".cert.ca")) {
+                		                                $vhost_file .= "        SSLCertificateChainFile $ssl_cert_folder_path/".$web_subname.".".$domain_to_get.".cert.ca\n";
+                                		        }
 							break;
 						}
 						$vhost_file .= "	ServerName $web_subname.$web_name
@@ -681,13 +795,20 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 						// Disable the site if expired
 						if($site_expired == "yes"){
 							$document_root = $conf_generated_file_path."/expired_site";
-							$vhost_file .= "	DocumentRoot $document_root\n";
-						}else{
-							$document_root = "$web_path/$web_name/subdomains/$web_subname/html";
 							$vhost_file .= "	DocumentRoot $document_root
+	<Directory $document_root>
+		Allow from all
+	</Directory>\n";
+						}else{
+							$document_root = "$web_path/$domain_to_get/subdomains/$web_subname/html";
+							$vhost_file .= "	DocumentRoot $document_root
+	<Directory $document_root>
+		Allow from all
+	</Directory>
 $vhost_more_conf	php_admin_value safe_mode $safe_mode_value
-	php_admin_value sendmail_from webmaster@$web_name
-	php_value session.save_path $web_path/$web_name/subdomains/$web_subname/tmp
+	php_admin_value sendmail_from phpmailfunction$web_subname@$web_name
+	php_admin_value sendmail_path \"/usr/sbin/sendmail -t -i -f phpmailfunction$web_subname@$domain_to_get\"
+	php_value session.save_path $web_path/$domain_to_get/subdomains/$web_subname/tmp
 	<Location />
 		php_admin_value open_basedir \"$web_path:$conf_php_library_path:$conf_php_additional_library_path:\"
 	</Location>
@@ -698,7 +819,13 @@ $vhost_more_conf	php_admin_value safe_mode $safe_mode_value
 	LogSQLScoreDomain $web_name
 	LogSQLScoreSubdomain $web_subname
 	LogSQLScoreTable $conf_mysql_db.http_accounting
-	DirectoryIndex index.php index.cgi index.pl index.htm index.html index.php4$custom_directives
+	DirectoryIndex $conf_apache_directoryindex$custom_directives
+	<IfModule mod_security.c>
+		SecUploadDir $web_path/$domain_to_get/subdomains/$web_subname/tmp
+	</IfModule>
+	<IfModule mod_cband.c>
+		CBandUser $web_owner
+	</IfModule>
 </VirtualHost>
 
 ";
@@ -805,4 +932,4 @@ $logrotate_template
 	return true;
 }
 
-?>
\ No newline at end of file
+?>
