@@ -374,6 +374,10 @@ function drawIPPoolConfig(){
 				"type" => "hyperlink",
 				"legend" => _("Customize"),
 				"text" => _("Customize") ),
+			"show_ip_pool_report" => array(
+				"type" => "hyperlink",
+				"legend" => _("show"),
+				"text" => _("Show") ),
 			"location" => array(
 				"type" => "text",
 				"legend" => _("Location")),
@@ -399,13 +403,17 @@ function drawIPPoolConfig(){
 			"zone_type" => array(
 				"type" => "popup",
 				"legend" => _("Type of zone generation"),
-				"values" => array("support_ticket", "ip_per_ip", "one_zonefile"),
-				"display_replace" => array(_("Support ticket"),_("One zonefile per IP"),_("One zonefile per pool")))
+				"values" => array("support_ticket", "ip_per_ip", "ip_per_ip_cidr", "one_zonefile"),
+				"display_replace" => array(_("Support ticket"),_("One zonefile per IP"),_("One zonefile per IP with net/cidr"),_("One zonefile per pool")))
 			)
 		);
 	$out .= dtcDatagrid($dsc);
 	$out .= "<br><br>";
 
+	if(isset($_REQUEST["show_ip_pool_report"])){
+		$out .= drawPool($_REQUEST["show_ip_pool_report"]);
+	}
+
 	if(isset($_REQUEST["editpool"])){
 		if(isset($_REQUEST["action"]) && $_REQUEST["action"] = "edit_custom_rdns_text"){
 			$q = "UPDATE $pro_mysql_ip_pool_table SET custom_part='".$_REQUEST["custom_part"]."' WHERE id='".$_REQUEST["editpool"]."';";
