@@ -41,45 +41,12 @@ function getCustomizedReminder($msg,$client,$remaining_days,$expiration_date,$ad
 	}
 	$msg_2_send = str_replace("%%%DTC_CLIENT_URL%%%","http".$surl."://".$conf_administrative_site."/dtc/",$msg_2_send);
 
-	if(file_exists("/etc/dtc/signature.txt")){
-		$fname = "/etc/dtc/signature.txt";
-	}else if(file_exists("/usr/local/www/dtc/etc/signature.txt")){
-		$fname = "/usr/local/www/dtc/etc/signature.txt";
-	}else{
-		$fname = "/usr/share/dtc/etc/signature.txt";
-	}
-	if(file_exists($fname)){
-		$fp = fopen($fname,"r");
-		if($fp != NULL){
-			$signature = fread($fp,filesize($fname));
-			fclose($fp);
-		}else{
-			$signature = "";
-		}
-	}else{
-		$signature = "";
-	}
+	// Add signature to the email
+	$signature = readCustomizedMessage("signature",$adm_login);
 	$msg_2_send = str_replace("%%%SIGNATURE%%%",$signature,$msg_2_send);
 
 	// Manage the header of the messages
-	if(file_exists("/etc/dtc/messages_header.txt")){
-		$fname = "/etc/dtc/messages_header.txt";
-	}else if(file_exists("/usr/local/www/dtc/etc/messages_header.txt")){
-		$fname = "/usr/local/www/dtc/etc/messages_header.txt";
-	}else{
-		$fname = "/usr/share/dtc/messages_header.txt";
-	}
-	if(file_exists($fname)){
-		$fp = fopen($fname,"r");
-		if($fp != NULL){
-			$head = fread($fp,filesize($fname));
-			fclose($fp);
-		}else{
-			$head = "";
-		}
-	}else{
-		$head = "";
-	}
+	$head = readCustomizedMessage("messages_header",$adm_login);
 	$msg_2_send = $head.$msg_2_send;
 
 	return $msg_2_send;
@@ -96,20 +63,7 @@ function sendVPSReminderEmail($remaining_days,$file,$send_webmaster_copy="no"){
 	global $conf_message_subject_header;
 	global $dtcshared_path;
 
-	// Using Debian, the files in /etc will be marked as conf files and then will be updated
-	// only if the admin asks for it. We just let Debian manage them...
-	if(file_exists("/etc/dtc/reminders_msg/".$file)){
-		$fname = "/etc/dtc/reminders_msg/".$file;
-	}else{
-		$fname = $dtcshared_path."/reminders_msg/".$file;
-	}
-	$fp = fopen($fname,"r");
-	if($fp != NULL){
-		$mesg = fread($fp,filesize($fname));
-		fclose($fp);
-	}else{
-		$mesg = "Could not load reminder message: please contact your administrator";
-	}
+	global $send_email_header;
 
 	$now_timestamp = mktime();
 	$one_day = 3600 * 24;
@@ -149,15 +103,17 @@ function sendVPSReminderEmail($remaining_days,$file,$send_webmaster_copy="no"){
 		$client = mysql_fetch_array($r2);
 
 		// Write the email
-		$msg_2_send = $mesg;
+		$msg_2_send = readCustomizedMessage($file,$admin["adm_login"]);
 		$msg_2_send = getCustomizedReminder($msg_2_send,$client["christname"],$remaining_days,$vps["expire_date"],$admin["adm_login"]);
 		$msg_2_send = str_replace("%%%VPS_NUMBER%%%",$vps["vps_xen_name"],$msg_2_send);
 		$msg_2_send = str_replace("%%%VPS_NODE%%%",$vps["vps_server_hostname"],$msg_2_send);
 
-		$headers = "From: ".$conf_webmaster_email_addr;
+		$headers = $send_email_header;
+		$headers .= "From: ".$conf_webmaster_email_addr;
 		mail($client["email"],"$conf_message_subject_header Your VPS expiration",$msg_2_send,$headers);
 		if($send_webmaster_copy == "yes"){
-			mail($conf_webmaster_email_addr,"$conf_message_subject_header A VPS has expired",$msg_2_send,$headers);
+			$subject = $admin["adm_login"] . "'s VPS " . $vps["vps_server_hostname"] . ":" . $vps["vps_xen_name"] . " expired " . $remaining_days . " ago";
+			mail($conf_webmaster_email_addr,"$conf_message_subject_header $subject",$msg_2_send,$headers);
 		}
 	}
 }
@@ -169,21 +125,21 @@ function sendVPSReminderEmail($remaining_days,$file,$send_webmaster_copy="no"){
 $before = explode("|",$conf_vps_renewal_before);
 $n = sizeof($before);
 for($i=0;$i<$n;$i++){
-	sendVPSReminderEmail($before[$i],"vps_will_expire.txt");
+	sendVPSReminderEmail($before[$i],"reminders_msg/vps_will_expire");
 }
 // Send reminders the day of the expiration
-sendVPSReminderEmail(0,"vps_expired_today.txt","no");
+sendVPSReminderEmail(0,"reminders_msg/vps_expired_today","no");
 // Send reminders after expiration
 $after = explode("|",$conf_vps_renewal_after);
 $n = sizeof($after);
 for($i=0;$i<$n;$i++){
 	$days = 0 - $after[$i];
-	sendVPSReminderEmail($days,"vps_expired_already.txt");
+	sendVPSReminderEmail($days,"reminders_msg/vps_expired_already");
 }
 // Send reminders for last warning
-sendVPSReminderEmail(-$conf_vps_renewal_lastwarning,"vps_expired_last_warning.txt","yes");
+sendVPSReminderEmail(-$conf_vps_renewal_lastwarning,"reminders_msg/vps_expired_last_warning","yes");
 // Send the shutdown message
-sendVPSReminderEmail(-$conf_vps_renewal_shutdown,"vps_expired_shutdown.txt","yes");
+sendVPSReminderEmail(-$conf_vps_renewal_shutdown,"reminders_msg/vps_expired_shutdown","yes");
 
 // Send all the mail for dedicated server for a given renew period
 function sendDedicatedReminderEmail($remaining_days,$file,$send_webmaster_copy="no"){
@@ -195,18 +151,7 @@ function sendDedicatedReminderEmail($remaining_days,$file,$send_webmaster_copy="
 	global $conf_message_subject_header;
 	global $dtcshared_path;
 
-	if(file_exists("/etc/dtc/reminders_msg/".$file)){
-		$fname = "/etc/dtc/reminders_msg/".$file;
-	}else{
-		$fname = "$dtcshared_path/registration_msg/".$file;
-	}
-	$fp = fopen($fname,"r");
-	if($fp != NULL){
-		$mesg = fread($fp,filesize($fname));
-		fclose($fp);
-	}else{
-		$msg = "";
-	}
+	global $send_email_header;
 
 	$now_timestamp = mktime();
 	$one_day = 3600 * 24;
@@ -226,7 +171,7 @@ function sendDedicatedReminderEmail($remaining_days,$file,$send_webmaster_copy="
 		}
 		$admin = mysql_fetch_array($r2);
 		if($admin["id_client"] == 0){
-			sendAdminWarning("Admin ".$vps["owner"]." has no client id (".$admin["id_client"].") line ".__LINE__." file ".__FILE__);
+			sendAdminWarning("Admin ".$dedicated["owner"]." has no client id (".$admin["id_client"].") line ".__LINE__." file ".__FILE__);
 			continue;
 		}
 
@@ -235,20 +180,22 @@ function sendDedicatedReminderEmail($remaining_days,$file,$send_webmaster_copy="
 		$r2 = mysql_query($q2)or die("Cannot query $q2 line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 		$n2 = mysql_num_rows($r2);
 		if($n2 != 1){
-			sendAdminWarning("Could not find id client ".$admin["id_client"]." for admin ".$vps["owner"]." line ".__LINE__." file ".__FILE__);
+			sendAdminWarning("Could not find id client ".$admin["id_client"]." for admin ".$dedicated["owner"]." line ".__LINE__." file ".__FILE__);
 			continue;
 		}
 		$client = mysql_fetch_array($r2);
 
 		// Write the email
-		$msg_2_send = $mesg;
+		$msg_2_send = readCustomizedMessage($file,$admin["adm_login"]);
 		$msg_2_send = getCustomizedReminder($msg_2_send,$client["christname"],$remaining_days,$dedicated["expire_date"],$admin["adm_login"]);
 		$msg_2_send = str_replace("%%%SERVER_HOSTNAME%%%",$dedicated["server_hostname"],$msg_2_send);
 
+		$headers = $send_email_header;
 		$headers = "From: ".$conf_webmaster_email_addr;
 		mail($client["email"],"$conf_message_subject_header Your dedicated server expiration",$msg_2_send,$headers);
 		if($send_webmaster_copy == "yes"){
-			mail($conf_webmaster_email_addr,"$conf_message_subject_header A dedicated has expired",$msg_2_send,$headers);
+			$subject = $admin["adm_login"] . "'s server " . $dedicated["server_hostname"] . " expired " . $remaining_days . " ago";
+			mail($conf_webmaster_email_addr,"$conf_message_subject_header $subject",$msg_2_send,$headers);
 		}
 	}
 }
@@ -260,21 +207,21 @@ function sendDedicatedReminderEmail($remaining_days,$file,$send_webmaster_copy="
 $before = explode("|",$conf_vps_renewal_before);
 $n = sizeof($before);
 for($i=0;$i<$n;$i++){
-	sendDedicatedReminderEmail($before[$i],"server_will_expire.txt");
+	sendDedicatedReminderEmail($before[$i],"reminders_msg/server_will_expire");
 }
 // Send reminders the day of the expiration
-sendDedicatedReminderEmail(0,"server_expired_today.txt","no");
+sendDedicatedReminderEmail(0,"reminders_msg/server_expired_today","no");
 // Send reminders after expiration
 $after = explode("|",$conf_vps_renewal_after);
 $n = sizeof($after);
 for($i=0;$i<$n;$i++){
 	$days = 0 - $after[$i];
-	sendDedicatedReminderEmail($days,"server_expired_already.txt");
+	sendDedicatedReminderEmail($days,"reminders_msg/server_expired_already");
 }
 // Send reminders for last warning
-sendDedicatedReminderEmail(-$conf_vps_renewal_lastwarning,"server_expired_last_warning.txt","yes");
+sendDedicatedReminderEmail(-$conf_vps_renewal_lastwarning,"reminders_msg/server_expired_last_warning","yes");
 // Send the shutdown message
-sendDedicatedReminderEmail(-$conf_vps_renewal_shutdown,"server_expired_shutdown.txt","yes");
+sendDedicatedReminderEmail(-$conf_vps_renewal_shutdown,"reminders_msg/server_expired_shutdown","yes");
 
 ///////////////////////////////
 // SHARED HOSTING EXPIRATION //
@@ -288,18 +235,7 @@ function sendSharedHostingReminderEmail($remaining_days,$file,$send_webmaster_co
 	global $conf_message_subject_header;
 	global $dtcshared_path;
 
-	if(file_exists("/etc/dtc/reminders_msg/".$file)){
-		$fname = "/etc/dtc/reminders_msg/".$file;
-	}else{
-		$fname = "$dtcshared_path/registration_msg/".$file;
-	}
-	$fp = fopen($fname,"r");
-	if($fp != NULL){
-		$mesg = fread($fp,filesize($fname));
-		fclose($fp);
-	}else{
-		$msg = "";
-	}
+	global $send_email_header;
 
 	$now_timestamp = mktime();
 	$one_day = 3600 * 24;
@@ -327,13 +263,15 @@ function sendSharedHostingReminderEmail($remaining_days,$file,$send_webmaster_co
 		$client = mysql_fetch_array($r2);
 
 		// Write the email
-		$msg_2_send = $mesg;
+		$msg_2_send = readCustomizedMessage($file,$admin["adm_login"]);
 		$msg_2_send = getCustomizedReminder($msg_2_send,$client["christname"],$remaining_days,$admin["expire"],$admin["adm_login"]);
 
-		$headers = "From: ".$conf_webmaster_email_addr;
+		$headers = $send_email_header;
+		$headers .= "From: ".$conf_webmaster_email_addr;
 		mail($client["email"],"$conf_message_subject_header Your shared hosting expiration",$msg_2_send,$headers);
 		if($send_webmaster_copy == "yes"){
-			mail($conf_webmaster_email_addr,"$conf_message_subject_header A shared hosting account has expired",$msg_2_send,$headers);
+			$subject = $admin["adm_login"] . "'s shared hosting package expired " . -$remaining_days . " ago";
+			mail($conf_webmaster_email_addr,"$conf_message_subject_header $subject",$msg_2_send,$headers);
 		}
 	}
 }
@@ -342,20 +280,20 @@ function sendSharedHostingReminderEmail($remaining_days,$file,$send_webmaster_co
 $before = explode("|",$conf_shared_renewal_before);
 $n = sizeof($before);
 for($i=0;$i<$n;$i++){
-	sendSharedHostingReminderEmail($before[$i],"shared_will_expire.txt");
+	sendSharedHostingReminderEmail($before[$i],"reminders_msg/shared_will_expire");
 }
 // Send reminder the day of expiration
-sendSharedHostingReminderEmail(0,"shared_expired_today.txt","no");
+sendSharedHostingReminderEmail(0,"reminders_msg/shared_expired_today","no");
 // Send reminders after expiration
 $after = explode("|",$conf_shared_renewal_after);
 $n = sizeof($after);
 for($i=0;$i<$n;$i++){
 	$days = 0 - $after[$i];
-	sendSharedHostingReminderEmail($days,"shared_expired_already.txt");
+	sendSharedHostingReminderEmail($days,"reminders_msg/shared_expired_already");
 }
 // Send last warning
-sendSharedHostingReminderEmail(-$conf_shared_renewal_lastwarning,"shared_expired_last_warning.txt","yes");
+sendSharedHostingReminderEmail(-$conf_shared_renewal_lastwarning,"reminders_msg/shared_expired_last_warning","yes");
 // Send rexpiration reminder
-sendSharedHostingReminderEmail(-$conf_shared_renewal_shutdown,"shared_expired_shutdown.txt","yes");
+sendSharedHostingReminderEmail(-$conf_shared_renewal_shutdown,"reminders_msg/shared_expired_shutdown","yes");
 
 ?>
