@@ -3,11 +3,15 @@
 function login_emailpanel_form(){
 	global $conf_skin;
 	
-	$HTML_admin_edit_data = "<a href=\"/dtc\">". _("Go to client panel") ."</a>
+	$HTML_admin_edit_data = "<a href=\"/dtc/\">"._("Client panel")."</a> -
+". _("Email panel") ." -
+<a href=\"/dtc/new_account.php\">". _("Register a new account") ."</a> -
+<a href=\"/dtc/recover_pass.php\">". _("Recover password"). "</a>
+
 <form action=\"".$_SERVER["PHP_SELF"]."\" method=\"post\">
 <table>
 <tr>
-	<td align=\"right\">". _("Login: ") ."</td>
+	<td align=\"right\">". _("Email: ") ."</td>
 	<td><input type=\"text\" name=\"adm_email_login\" value=\"\"></td>
 </tr><tr>
 	<td align=\"right\">". _("Password: ") ."</td>
