@@ -61,7 +61,7 @@ if($sousrub == "dtc"){
 	$ZeContentWindowTitle = "DTC Client interface|dtc.gif";
 	$ZeContent = '
 <div id="FRAMEDIV_ID" style="width:100%;height:100%;display:none;">
-<iframe id="FRAME_ID" allowtransparency="true" overflow="visible" frameborder="0" src="//'.$_SERVER["HTTP_HOST"].'/dtc" width="100%">  </iframe>
+<iframe id="FRAME_ID" allowtransparency="true" overflow="visible" frameborder="0" src="//'.$_SERVER["HTTP_HOST"].'/dtc/" width="100%">  </iframe>
       </div>
 ';
 }
@@ -78,7 +78,7 @@ if($sousrub == "squirrelmail"){
 if($sousrub == "dtcadmin"){
 	$ZeContentWindowTitle = "DTC Client interface|dtc.gif";
 	$ZeContent = '<div id="FRAMEDIV_ID" style="width:100%;height:100%;display:none;">
-<iframe id="FRAME_ID" allowtransparency="true" overflow="visible" frameborder="0" src="//'.$_SERVER["HTTP_HOST"].'/dtcadmin" width="100%">  </iframe>
+<iframe id="FRAME_ID" allowtransparency="true" overflow="visible" frameborder="0" src="//'.$_SERVER["HTTP_HOST"].'/dtcadmin/" width="100%">  </iframe>
       </div>
 ';
 }
@@ -86,7 +86,7 @@ if($sousrub == "dtcadmin"){
 if($sousrub == "dtcemail"){
 	$ZeContentWindowTitle = "DTC Email interface|dtc.gif";
 	$ZeContent = '<div id="FRAMEDIV_ID" style="width:100%;height:100%;display:none;">
-<iframe id="FRAME_ID" allowtransparency="true" overflow="visible" frameborder="0" src="//'.$_SERVER["HTTP_HOST"].'/dtcemail" width="100%">  </iframe>
+<iframe id="FRAME_ID" allowtransparency="true" overflow="visible" frameborder="0" src="//'.$_SERVER["HTTP_HOST"].'/dtcemail/" width="100%">  </iframe>
       </div>
 ';
 }
@@ -94,7 +94,7 @@ if($sousrub == "dtcemail"){
 if($sousrub == "phpmyadmin"){
 	$ZeContentWindowTitle = "PhpMyAdmin|mysql.png";
 	$ZeContent = '<div id="FRAMEDIV_ID" style="width:100%;height:100%;display:none;">
-<iframe id="FRAME_ID" allowtransparency="true" overflow="visible" frameborder="0" src="//'.$_SERVER["HTTP_HOST"].'/phpmyadmin" width="100%">  </iframe>
+<iframe id="FRAME_ID" allowtransparency="true" overflow="visible" frameborder="0" src="//'.$_SERVER["HTTP_HOST"].'/phpmyadmin/" width="100%">  </iframe>
       </div>
 ';
 }
