@@ -19,8 +19,8 @@ function deleteMysqlUserAndDB($adm_login){
 			$db = $row["Db"];
 			// Prevent system db from deletion
 			if($db != $conf_mysql_db && $db != "mysql"){
-				$query2 = "DROP DATABASE $db";
-				mysql_query($query2)or die("Cannot execute query \"$query\" !!!");
+				$query2 = "DROP DATABASE IF EXISTS $db";
+				mysql_query($query2)or die("Cannot execute query \"$query2\" line ".__line__." file ".__FILE__." mysql said: ".mysql_error());
 			}
 		}
 		// Prevent system user from deletion
@@ -44,16 +44,15 @@ function deleteUserDomain($adm_login,$adm_pass,$deluserdomain,$delete_directorie
 	global $pro_mysql_subdomain_table;
 	global $pro_mysql_domain_table;
 	global $pro_mysql_list_table;
+	global $pro_mysql_fetchmail_table;
+	global $pro_mysql_cronjob_table;
 	global $conf_demo_version;
 
 	global $conf_root_admin_random_pass;
 	global $conf_pass_expire;
 
-	if($conf_root_admin_random_pass == $adm_pass &&  $conf_pass_expire > mktime()){
-		$adm_query = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='$adm_login';";
-	}else{
-		$adm_query = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='$adm_login' AND (adm_pass='$adm_pass' OR (pass_next_req='$adm_pass' AND pass_expire > '".mktime()."'));";
-	}
+	checkLoginPassAndDomain($adm_login,$adm_pass,$deluserdomain);
+	$adm_query = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='$adm_login';";
 	$result = mysql_query($adm_query)or die("Cannot execute query \"$adm_query\" line ".__LINE__." file ".__FILE__."sql said ".mysql_error());
 	$num_rows = mysql_num_rows($result);
 	if($num_rows != 1) die("User not found for deletion of domain $deluserdomain !!!");
@@ -68,6 +67,9 @@ function deleteUserDomain($adm_login,$adm_pass,$deluserdomain,$delete_directorie
 	$adm_query = "DELETE FROM $pro_mysql_pop_table WHERE mbox_host='$deluserdomain';";
 	mysql_query($adm_query)or die("Cannot execute query \"$adm_query\" !!!");
 
+	$adm_query = "DELETE FROM $pro_mysql_fetchmail_table WHERE domain_name='$deluserdomain';";
+	mysql_query($adm_query)or die("Cannot execute query \"$adm_query\" !!!");
+
 	// Delete all mailboxs
 	$adm_query = "DELETE FROM $pro_mysql_ftp_table WHERE hostname='$deluserdomain';";
 	mysql_query($adm_query)or die("Cannot execute query \"$adm_query\" !!!");
@@ -88,6 +90,19 @@ function deleteUserDomain($adm_login,$adm_pass,$deluserdomain,$delete_directorie
 	if($delete_directories == true && $conf_demo_version == "no"){
 		system("rm -rf $the_admin_path/$deluserdomain");
 	}
+
+	// We now check if there are still some domains in the admin account
+	// if there are none, then we shall delete the symlinks
+	$adm_query = "SELECT name FROM $pro_mysql_domain_table WHERE owner='$adm_login';";
+	$r = mysql_query($adm_query)or die("Cannot execute query \"$adm_query\" line ".__LINE__." file ".__FILE__);
+	$n = mysql_num_rows($r);
+	if($n == 0){
+		system("rm -rf $the_admin_path/lib $the_admin_path/dev $the_admin_path/etc $the_admin_path/sbin $the_admin_path/tmp $the_admin_path/usr $the_admin_path/var $the_admin_path/bin $the_admin_path/lib64 $the_admin_path/libexec");
+	}
+
+	$adm_query = "UPDATE $pro_mysql_cronjob_table SET qmail_newu='yes',restart_qmail='yes',reload_named='yes',
+	restart_apache='yes',gen_vhosts='yes',gen_named='yes',gen_qmail='yes',gen_webalizer='yes',gen_backup='yes',gen_ssh='yes',gen_fetchmail='yes' WHERE 1;";
+	mysql_query($adm_query);
 	triggerDomainListUpdate();
 }
 
@@ -164,7 +179,7 @@ function DTCdeleteAdmin ($adm_to_del) {
 
 	// Tell the cron job to activate the changes (in case there was some shared accounts. Todo: check if there is some...)
 	$adm_query = "UPDATE $pro_mysql_cronjob_table SET qmail_newu='yes',restart_qmail='yes',reload_named='yes',
-	restart_apache='yes',gen_vhosts='yes',gen_named='yes',gen_qmail='yes',gen_webalizer='yes',gen_backup='yes',gen_ssh='yes' WHERE 1;";
+	restart_apache='yes',gen_vhosts='yes',gen_named='yes',gen_qmail='yes',gen_webalizer='yes',gen_backup='yes',gen_ssh='yes',gen_fetchmail='yes' WHERE 1;";
 	mysql_query($adm_query);
 	triggerDomainListUpdate();
 }
