@@ -6,11 +6,30 @@ function drawAdminTools_Invoices($admin){
 	global $pro_mysql_companies_table;
 	global $pro_mysql_product_table;
 	global $pro_mysql_pay_table;
+	global $pro_mysql_companies_table;
+	global $conf_default_company_invoicing;
+
 	global $adm_login;
 	global $adm_pass;
 
 	$out = "";
 
+	$q = "SELECT * FROM $pro_mysql_companies_table WHERE 1;";
+	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+	$n = mysql_num_rows($r);
+	if($n == 0){
+		$out = _("There is no company defined: impossible to show invoices. Contact your administrator.");
+		return $out;
+	}
+
+	$q = "SELECT * FROM $pro_mysql_companies_table WHERE id='".$conf_default_company_invoicing."';";
+	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+	$n = mysql_num_rows($r);
+	if($n == 0){
+		$out = _("There is no default invoincing company set: impossible to show invoices. Contact your administrator.");
+		return $out;
+	}
+
 	$q = "SELECT * FROM $pro_mysql_completedorders_table WHERE id_client='".$admin["client"]["id"]."';";
 	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 	$n = mysql_num_rows($r);
